Version 0.2.2 (2014-08-28)
==========================
  - Integrate ``setup.py`` with unit tests
  - Documentation fixes
  - Continous integration
  - PEP8 compliance
  - Online API documentation
  - Minor enhancement of code

Version 0.2.1 (2014-08-13)
==========================
  - Fixing a bug from distuils.core that stop installation from running

Version 0.2 (2014-08-13)
========================
  - Fixing documentation

Version 0.1 (2014-08-12)
========================
  - Initial Release
